==> nextcloud-13.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/de.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Einrichtungsassistent",
    "Add your profile information! For example your email is needed to reset your password." : "Füge deine Profil-Informationen hinzu! Z.B. wird deine E-Mail-Adresse zum Zurücksetzen deines Passwortes benötigt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Setze ein Profilbild und gib Deinen vollständigen Namen ein, damit Du einfacher erkannt werden kannst.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Gib Deinen vollständigen Namen ein, damit Du einfacher erkannt werden kannst.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Setze ein Profilbild, damit Du einfacher erkannt werden kannst.",
    "Get the apps to sync your files" : "Lade die Apps zur Synchronisierung Deiner Daten herunter",
    "Desktop client" : "Desktop-Client",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Wenn Du das Projekt unterstützen willst, {contributeopen}hilf bei der Entwicklung{linkclose} oder {contributeopen}verbreite es{linkclose}!",
    "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Greife auf und teile deine Dateien, Kalender, Kontakte, E-Mail und mehr von jedem Gerät aus, zu deinen Bedingungen",
    "Connect your desktop apps to %s" : "Verbinde Deine Desktop-Anwendungen mit %s",
    "Connect your calendar" : "Verbinde Deine Kalender ",
    "Connect your contacts" : "Verbinde Deine Kontakte",
    "Access files via WebDAV" : "Greife auf Dateien über WebDAV zu",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Weitere Informationenfindest Du in der <a target=\"_blank\" href=\"%s\">Dokumentation</a> und auf unserer  <a target=\"_blank\" href=\"%s\">Webseite</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Wenn Du Nextcloud gut findest, <a href=\"mailto:?subject=Nextcloud&body=Nextcloud ist eine tolle Software zur Synchronisation und zum Teilen von Dateien. Es ist kostenlos erhältlich unter https://nextcloud.com\">Empfehle es Bekannten und Freunden</a> und <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">unterstütze Nextcloud</a>!",
    "Connect your Calendar" : "Verbinde Deine Kalender ",
    "Connect your Contacts" : "Verbinde Deine Kontakte"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-13.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/firstrunwizard/l10n/de.js <==
OC.L10N.register(
    "firstrunwizard",
    {
    "First run wizard" : "Einrichtungsassistent",
    "Add your profile information! For example your email is needed to reset your password." : "Füge deine Profil-Informationen hinzu! Z.B. wird deine E-Mail-Adresse zum Zurücksetzen deines Passwortes benötigt.",
    "Add your profile information! Set a profile picture and full name for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Setze ein Profilbild und gib Deinen vollständigen Namen ein, damit Du einfacher erkannt werden kannst.",
    "Add your profile information! Set a full name for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Gib Deinen vollständigen Namen ein, damit Du einfacher erkannt werden kannst.",
    "Add your profile information! Set a profile picture for easier recognition across all features." : "Füge Deine Profilinformationen hinzu! Setze ein Profilbild, damit Du einfacher erkannt werden kannst.",
    "Get the apps to sync your files" : "Lade die Apps zur Synchronisierung Deiner Daten herunter",
    "%s gives you access to your files wherever you are. Our easy to use desktop and mobile clients are available for all major platforms at zero cost." : "%s erlaubt Dir den Zugriff auf Deine Dateien, egal wo Du bist. Unser Desktop-Client und die mobilen Apps sind kostenfrei für alle wichtigen Plattformen verfügbar.",
    "Desktop client" : "Desktop-Client",
    "Android app" : "Android-App",
    "iOS app" : "iOS-App",
    "Setup sync clients using an <a href=\"\">app password</a>. That way you can make sure you are able to revoke access in case you loose that device." : "Verwende ein <a href=\"\">App-Passwort</a> beim Einrichten der Sync-Clients. Dadurch kannst Du den Zugriff sperren, falls Dir das Gerät verloren geht.",
    "Connect other apps to %s" : "Verbinde andere Apps mit %s",
    "Besides the sync clients you can connect any other software that supports the WebDAV/CalDAV/CardDAV protocols to %s." : "Du kannst zur Verbindung zu %s außer den Sync-Clients jede andere Software verwenden, welche die Protokolle WebDAV/CalDAV/CardDAV unterstützt.",
    "Connect your calendar" : "Verbinde Deine Kalender ",
    "Connect your contacts" : "Verbinde Deine Kontakte",
    "Access files via WebDAV" : "Greife auf Dateien über WebDAV zu",
    "The first run wizard helps you to get started with %s." : "Dieser Einrichtungsassistent hilft Dir beim Start mit %s.",
    "Show first run wizard again" : "Den Einrichtungsassistenten erneut anzeigen",
    "Access & share your files, calendars, contacts, mail & more from any device, on your terms" : "Greife auf und teile deine Dateien, Kalender, Kontakte, E-Mail und mehr von jedem Gerät aus, zu deinen Bedingungen",
    "Connect your desktop apps to %s" : "Verbinde Deine Desktop-Anwendungen mit %s",
    "There’s more information in the <a target=\"_blank\" href=\"%s\">documentation</a> and on our <a target=\"_blank\" href=\"%s\">website</a>." : "Weitere Informationenfindest Du in der <a target=\"_blank\" href=\"%s\">Dokumentation</a> und auf unserer  <a target=\"_blank\" href=\"%s\">Webseite</a>.",
    "If you like Nextcloud, <a href=\"mailto:?subject=Nextcloud &body=Nextcloud is a great open software to sync and share your files. You can freely get it from https://nextcloud.com\"> recommend it to your friends</a> and <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">contribute back</a>!" : "Wenn Du Nextcloud gut findest, <a href=\"mailto:?subject=Nextcloud&body=Nextcloud ist eine tolle Software zur Synchronisation und zum Teilen von Dateien. Es ist kostenlos erhältlich unter https://nextcloud.com\">Empfehle es Bekannten und Freunden</a> und <a href=\"https://nextcloud.com/contribute/\" target=\"_blank\">unterstütze Nextcloud</a>!",
    "Connect your Calendar" : "Verbinde Deine Kalender ",
    "Connect your Contacts" : "Verbinde Deine Kontakte",
    "If you want to support the project {contributeopen}join development{linkclose} or {contributeopen}spread the word{linkclose}!" : "Wenn Du das Projekt unterstützen willst, {contributeopen}hilf bei der Entwicklung{linkclose} oder {contributeopen}verbreite es{linkclose}!",
    "Show First Run Wizard again" : "Den Einrichtungsassistenten erneut anzeigen"
},
"nplurals=2; plural=(n != 1);");
